/*
 * Copyright (c) 2021, Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 *  ============ ti_msp_dl_config.h =============
 *  Configured MSPM0 DriverLib module declarations
 *
 *  DO NOT EDIT - This file is generated for the MSPM0L130X
 *  by the SysConfig tool.
 */
#ifndef ti_msp_dl_config_h
#define ti_msp_dl_config_h

#define CONFIG_MSPM0L130X

#if defined(__ti_version__) || defined(__TI_COMPILER_VERSION__)
#define SYSCONFIG_WEAK __attribute__((weak))
#elif defined(__IAR_SYSTEMS_ICC__)
#define SYSCONFIG_WEAK __weak
#elif defined(__GNUC__)
#define SYSCONFIG_WEAK __attribute__((weak))
#endif

#include <ti/devices/msp/msp.h>
#include <ti/driverlib/driverlib.h>
#include <ti/driverlib/m0p/dl_core.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 *  ======== SYSCFG_DL_init ========
 *  Perform all required MSP DL initialization
 *
 *  This function should be called once at a point before any use of
 *  MSP DL.
 */


/* clang-format off */

#define POWER_STARTUP_DELAY                                                (16)


#define CPUCLK_FREQ                                                     32000000



/* Defines for TIMER_0 */
#define TIMER_0_INST                                                     (TIMG0)
#define TIMER_0_INST_IRQHandler                                 TIMG0_IRQHandler
#define TIMER_0_INST_INT_IRQN                                   (TIMG0_INT_IRQn)
#define TIMER_0_INST_LOAD_VALUE                                          (1249U)



/* Defines for UART_R */
#define UART_R_INST                                                        UART0
#define UART_R_INST_IRQHandler                                  UART0_IRQHandler
#define UART_R_INST_INT_IRQN                                      UART0_INT_IRQn
#define GPIO_UART_R_RX_PORT                                                GPIOA
#define GPIO_UART_R_TX_PORT                                                GPIOA
#define GPIO_UART_R_RX_PIN                                        DL_GPIO_PIN_26
#define GPIO_UART_R_TX_PIN                                        DL_GPIO_PIN_25
#define GPIO_UART_R_IOMUX_RX                                     (IOMUX_PINCM27)
#define GPIO_UART_R_IOMUX_TX                                     (IOMUX_PINCM26)
#define GPIO_UART_R_IOMUX_RX_FUNC                      IOMUX_PINCM27_PF_UART0_RX
#define GPIO_UART_R_IOMUX_TX_FUNC                      IOMUX_PINCM26_PF_UART0_TX
#define UART_R_BAUD_RATE                                                  (1200)
#define UART_R_IBRD_32_MHZ_1200_BAUD                                      (1666)
#define UART_R_FBRD_32_MHZ_1200_BAUD                                        (43)
/* Defines for UART_L */
#define UART_L_INST                                                        UART1
#define UART_L_INST_IRQHandler                                  UART1_IRQHandler
#define UART_L_INST_INT_IRQN                                      UART1_INT_IRQn
#define GPIO_UART_L_RX_PORT                                                GPIOA
#define GPIO_UART_L_TX_PORT                                                GPIOA
#define GPIO_UART_L_RX_PIN                                        DL_GPIO_PIN_11
#define GPIO_UART_L_TX_PIN                                        DL_GPIO_PIN_10
#define GPIO_UART_L_IOMUX_RX                                     (IOMUX_PINCM12)
#define GPIO_UART_L_IOMUX_TX                                     (IOMUX_PINCM11)
#define GPIO_UART_L_IOMUX_RX_FUNC                      IOMUX_PINCM12_PF_UART1_RX
#define GPIO_UART_L_IOMUX_TX_FUNC                      IOMUX_PINCM11_PF_UART1_TX
#define UART_L_BAUD_RATE                                                  (1200)
#define UART_L_IBRD_32_MHZ_1200_BAUD                                      (1666)
#define UART_L_FBRD_32_MHZ_1200_BAUD                                        (43)





/* Port definition for Pin Group GPIO_General */
#define GPIO_General_PORT                                                (GPIOA)

/* Defines for O_LED: GPIOA.24 with pinCMx 25 on package pin 27 */
#define GPIO_General_O_LED_PIN                                  (DL_GPIO_PIN_24)
#define GPIO_General_O_LED_IOMUX                                 (IOMUX_PINCM25)
/* Defines for I_HALL: GPIOA.17 with pinCMx 18 on package pin 20 */
// pins affected by this interrupt request:["I_HALL"]
#define GPIO_General_INT_IRQN                                   (GPIOA_INT_IRQn)
#define GPIO_General_INT_IIDX                   (DL_INTERRUPT_GROUP1_IIDX_GPIOA)
#define GPIO_General_I_HALL_IIDX                            (DL_GPIO_IIDX_DIO17)
#define GPIO_General_I_HALL_PIN                                 (DL_GPIO_PIN_17)
#define GPIO_General_I_HALL_IOMUX                                (IOMUX_PINCM18)
/* Defines for O_REN: GPIOA.27 with pinCMx 28 on package pin 2 */
#define GPIO_General_O_REN_PIN                                  (DL_GPIO_PIN_27)
#define GPIO_General_O_REN_IOMUX                                 (IOMUX_PINCM28)
/* Defines for O_Charger_EN: GPIOA.4 with pinCMx 5 on package pin 11 */
#define GPIO_General_O_Charger_EN_PIN                            (DL_GPIO_PIN_4)
#define GPIO_General_O_Charger_EN_IOMUX                           (IOMUX_PINCM5)
/* Defines for O_Charger_COM: GPIOA.3 with pinCMx 4 on package pin 10 */
#define GPIO_General_O_Charger_COM_PIN                           (DL_GPIO_PIN_3)
#define GPIO_General_O_Charger_COM_IOMUX                          (IOMUX_PINCM4)
/* Defines for O_LEN: GPIOA.9 with pinCMx 10 on package pin 14 */
#define GPIO_General_O_LEN_PIN                                   (DL_GPIO_PIN_9)
#define GPIO_General_O_LEN_IOMUX                                 (IOMUX_PINCM10)

/* clang-format on */

void SYSCFG_DL_init(void);
void SYSCFG_DL_initPower(void);
void SYSCFG_DL_GPIO_init(void);
void SYSCFG_DL_SYSCTL_init(void);
void SYSCFG_DL_TIMER_0_init(void);
void SYSCFG_DL_UART_R_init(void);
void SYSCFG_DL_UART_L_init(void);



#ifdef __cplusplus
}
#endif

#endif /* ti_msp_dl_config_h */
